import React, { useState } from 'react';
import axios from 'axios';
import { Link, useNavigate } from 'react-router-dom';
import './Register.css';

const Register = () => {
  const navigate = useNavigate();
  const [formData, setFormData] = useState({
    username: '',
    email: '',
    password: '',
    phone: '',
    image: null,
  });
  const [message, setMessage] = useState('');

  // تحديث بيانات الحقول
  const handleChange = (e) => {
    const { name, value } = e.target;
    setFormData({ ...formData, [name]: value });
  };

  // تحديث الصورة
  const handleImageChange = (e) => {
    setFormData({ ...formData, image: e.target.files[0] });
  };

  // التحقق من صحة المدخلات
  const validateInputs = () => {
    const usernameRegex = /^[a-zA-Z0-9]{3,15}$/; // حروف وأرقام فقط، بين 3-15 حرفًا
    const passwordRegex = /^[a-zA-Z0-9!@#$%^&*()-_=+]{6,}$/; // كلمة المرور بها رموز وأرقام وحروف (لا تقبل العربية)
    const phoneRegex = /^[0-9]{9,15}$/; // أرقام فقط، لا تقل عن 9 ولا تزيد عن 15 رقمًا
    const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/; // صيغة بريد إلكتروني صحيحة

    if (!formData.username) {
      setMessage('يرجى إدخال اسم المستخدم.');
      return false;
    }
    if (!usernameRegex.test(formData.username)) {
      setMessage('اسم المستخدم يجب أن يكون بين 3-15 حرفًا، بدون مسافات أو رموز.');
      return false;
    }

    if (!formData.email) {
      setMessage('يرجى إدخال البريد الإلكتروني.');
      return false;
    }
    if (!emailRegex.test(formData.email)) {
      setMessage('الرجاء إدخال بريد إلكتروني صحيح.');
      return false;
    }

    if (!formData.password) {
      setMessage('يرجى إدخال كلمة المرور.');
      return false;
    }
    if (!passwordRegex.test(formData.password)) {
      setMessage('كلمة المرور يجب أن تتكون من حروف وأرقام ورموز، ولا تقبل اللغة العربية.');
      return false;
    }

    if (!formData.phone) {
      setMessage('يرجى إدخال رقم الهاتف.');
      return false;
    }
    if (!phoneRegex.test(formData.phone)) {
      setMessage('رقم الهاتف يجب أن يكون 10 أرقام على الأقل ولا يزيد عن 15 رقمًا.');
      return false;
    }

    return true;
  };

  // إرسال البيانات إلى الخادم
  const handleSubmit = async (e) => {
    e.preventDefault();

    if (!validateInputs()) {
      return;
    }

    const form = new FormData();

    // إضافة البيانات إلى FormData
    form.append('username', formData.username);
    form.append('email', formData.email);
    form.append('password', formData.password);
    form.append('phone', formData.phone);
    if (formData.image) {
      form.append('image', formData.image);
    }

    try {
      const response = await axios.post('https://ads2030.com/api/register', form, {
        headers: { 'Content-Type': 'multipart/form-data' },
      });
      setMessage(response.data.message);
      setFormData({
        username: '',
        email: '',
        password: '',
        phone: '',
        image: null,
      });
      alert(response.data.message);
      navigate('/login');
    } catch (error) {
      setMessage(error.response?.data?.message || 'حدث خطأ أثناء تسجيل المستخدم.');
    }
  };

  return (
    <div className="register-page">
      {/* الهيدر الأول */}
      <header className="header header1">
        <img src="/logo/001.png" alt="Logo" className="logo-image" />
        <span className="site-name">إعلانات 2030</span>
      </header>

      {/* الهيدر الثاني */}
      <header className="header header2">
        <div className="button-container">
          <button className="button">
            <Link to="/">الرئيسية</Link>
          </button>
          <button className="button">
            <Link to="/login">تسجيل الدخول</Link>
          </button>
          <button className="button">
            <Link to="/register">تسجيل جديد</Link>
          </button>
        </div>
      </header>

      {/* قسم تسجيل مستخدم جديد */}
      <div className="register-container">
        <h1 className="register-title">تسجيل مستخدم جديد</h1>
        {message && <p className="register-message">{message}</p>}
        <form className="register-form" onSubmit={handleSubmit}>
          <div>
            <input
              type="text"
              name="username"
              placeholder="اسم المستخدم"
              value={formData.username}
              onChange={handleChange}
              className="register-input"
            />
          </div>
          <div>
            <input
              type="email"
              name="email"
              placeholder="البريد الإلكتروني"
              value={formData.email}
              onChange={handleChange}
              className="register-input"
            />
          </div>
          <div>
            <input
              type="password"
              name="password"
              placeholder="كلمة المرور"
              value={formData.password}
              onChange={handleChange}
              className="register-input"
            />
          </div>
          <div>
            <input
              type="text"
              name="phone"
              placeholder="رقم الهاتف"
              value={formData.phone}
              onChange={handleChange}
              className="register-input"
            />
          </div>
          <div>
            <input
              type="file"
              name="image"
              accept="image/*"
              onChange={handleImageChange}
              className="register-input"
            />
          </div>
          <div>
            <button type="submit" className="register-button">
              تسجيل جديد
            </button>
          </div>
        </form>
      </div>
    </div>
  );
};

export default Register;
